@@ -6,17 +6,17 @@ from hatchling.utils.constants import DEFAULT_CONFIG_FILE
 
 
 def test_unknown(hatch, temp_dir_data, helpers):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'foo')
+        result = hatch("env", "remove", "foo")
 
     assert result.exit_code == 1, result.output
     assert result.output == helpers.dedent(
@@ -27,51 +27,51 @@ def test_unknown(hatch, temp_dir_data, helpers):
 
 
 def test_nonexistent(hatch, temp_dir_data):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'default')
+        result = hatch("env", "remove", "default")
 
     assert result.exit_code == 0, result.output
     assert not result.output
 
 
 def test_single(hatch, helpers, temp_dir_data, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     project = Project(project_path)
-    helpers.update_project_environment(project, 'default', {'skip-install': True, **project.config.envs['default']})
-    helpers.update_project_environment(project, 'foo', {})
-    helpers.update_project_environment(project, 'bar', {})
+    helpers.update_project_environment(project, "default", {"skip-install": True, **project.config.envs["default"]})
+    helpers.update_project_environment(project, "foo", {})
+    helpers.update_project_environment(project, "bar", {})
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'foo')
+        result = hatch("env", "create", "foo")
 
     assert result.exit_code == 0, result.output
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'bar')
+        result = hatch("env", "create", "bar")
 
     assert result.exit_code == 0, result.output
 
-    env_data_path = temp_dir_data / 'data' / 'env' / 'virtual'
+    env_data_path = temp_dir_data / "data" / "env" / "virtual"
     assert env_data_path.is_dir()
 
     project_data_path = env_data_path / project_path.name
@@ -86,14 +86,14 @@ def test_single(hatch, helpers, temp_dir_data, config_file):
     env_dirs = list(storage_path.iterdir())
     assert len(env_dirs) == 2
 
-    foo_env_path = storage_path / 'foo'
-    bar_env_path = storage_path / 'bar'
+    foo_env_path = storage_path / "foo"
+    bar_env_path = storage_path / "bar"
 
     assert foo_env_path.is_dir()
     assert bar_env_path.is_dir()
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'bar')
+        result = hatch("env", "remove", "bar")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -107,34 +107,34 @@ def test_single(hatch, helpers, temp_dir_data, config_file):
 
 
 def test_all(hatch, helpers, temp_dir_data, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     project = Project(project_path)
-    helpers.update_project_environment(project, 'default', {'skip-install': True, **project.config.envs['default']})
-    helpers.update_project_environment(project, 'foo', {})
-    helpers.update_project_environment(project, 'bar', {})
+    helpers.update_project_environment(project, "default", {"skip-install": True, **project.config.envs["default"]})
+    helpers.update_project_environment(project, "foo", {})
+    helpers.update_project_environment(project, "bar", {})
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'foo')
+        result = hatch("env", "create", "foo")
 
     assert result.exit_code == 0, result.output
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'bar')
+        result = hatch("env", "create", "bar")
 
     assert result.exit_code == 0, result.output
 
-    env_data_path = temp_dir_data / 'data' / 'env' / 'virtual'
+    env_data_path = temp_dir_data / "data" / "env" / "virtual"
     assert env_data_path.is_dir()
 
     project_data_path = env_data_path / project_path.name
@@ -149,14 +149,14 @@ def test_all(hatch, helpers, temp_dir_data, config_file):
     env_dirs = list(storage_path.iterdir())
     assert len(env_dirs) == 2
 
-    foo_env_path = storage_path / 'foo'
-    bar_env_path = storage_path / 'bar'
+    foo_env_path = storage_path / "foo"
+    bar_env_path = storage_path / "bar"
 
     assert foo_env_path.is_dir()
     assert bar_env_path.is_dir()
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'foo')
+        result = hatch("env", "remove", "foo")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -166,7 +166,7 @@ def test_all(hatch, helpers, temp_dir_data, config_file):
     )
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'bar')
+        result = hatch("env", "remove", "bar")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -179,28 +179,28 @@ def test_all(hatch, helpers, temp_dir_data, config_file):
 
 
 def test_matrix_all(hatch, helpers, temp_dir_data, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     project = Project(project_path)
-    helpers.update_project_environment(project, 'default', {'skip-install': True, **project.config.envs['default']})
-    helpers.update_project_environment(project, 'foo', {'matrix': [{'version': ['9000', '42']}]})
+    helpers.update_project_environment(project, "default", {"skip-install": True, **project.config.envs["default"]})
+    helpers.update_project_environment(project, "foo", {"matrix": [{"version": ["9000", "42"]}]})
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'foo')
+        result = hatch("env", "create", "foo")
 
     assert result.exit_code == 0, result.output
 
-    env_data_path = temp_dir_data / 'data' / 'env' / 'virtual'
+    env_data_path = temp_dir_data / "data" / "env" / "virtual"
     assert env_data_path.is_dir()
 
     project_data_path = env_data_path / project_path.name
@@ -215,14 +215,14 @@ def test_matrix_all(hatch, helpers, temp_dir_data, config_file):
     env_dirs = list(storage_path.iterdir())
     assert len(env_dirs) == 2
 
-    foo_env_path = storage_path / 'foo.42'
-    bar_env_path = storage_path / 'foo.9000'
+    foo_env_path = storage_path / "foo.42"
+    bar_env_path = storage_path / "foo.9000"
 
     assert foo_env_path.is_dir()
     assert bar_env_path.is_dir()
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'foo')
+        result = hatch("env", "remove", "foo")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -236,38 +236,38 @@ def test_matrix_all(hatch, helpers, temp_dir_data, config_file):
 
 
 def test_matrix_all_local_directory(hatch, helpers, temp_dir_data, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
-    config_file.model.dirs.env = {'virtual': '.hatch'}
+    config_file.model.template.plugins["default"]["tests"] = False
+    config_file.model.dirs.env = {"virtual": ".hatch"}
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     project = Project(project_path)
-    helpers.update_project_environment(project, 'default', {'skip-install': True, **project.config.envs['default']})
-    helpers.update_project_environment(project, 'foo', {'matrix': [{'version': ['9000', '42']}]})
+    helpers.update_project_environment(project, "default", {"skip-install": True, **project.config.envs["default"]})
+    helpers.update_project_environment(project, "foo", {"matrix": [{"version": ["9000", "42"]}]})
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'foo')
+        result = hatch("env", "create", "foo")
 
     assert result.exit_code == 0, result.output
 
-    env_data_path = project_path / '.hatch'
+    env_data_path = project_path / ".hatch"
     assert env_data_path.is_dir()
 
     env_dirs = list(env_data_path.iterdir())
     assert len(env_dirs) == 3
 
-    assert sorted(entry.name for entry in env_dirs) == ['.gitignore', 'foo.42', 'foo.9000']
+    assert sorted(entry.name for entry in env_dirs) == [".gitignore", "foo.42", "foo.9000"]
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'foo')
+        result = hatch("env", "remove", "foo")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -281,39 +281,39 @@ def test_matrix_all_local_directory(hatch, helpers, temp_dir_data, config_file):
 
 
 def test_incompatible_ok(hatch, helpers, temp_dir_data):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     project = Project(project_path)
     helpers.update_project_environment(
-        project, 'default', {'skip-install': True, 'platforms': ['foo'], **project.config.envs['default']}
+        project, "default", {"skip-install": True, "platforms": ["foo"], **project.config.envs["default"]}
     )
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove')
+        result = hatch("env", "remove")
 
     assert result.exit_code == 0, result.output
     assert not result.output
 
 
 def test_active(hatch, temp_dir_data, helpers):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
-    with project_path.as_cwd(env_vars={AppEnvVars.ENV_ACTIVE: 'default'}):
-        result = hatch('env', 'remove')
+    with project_path.as_cwd(env_vars={AppEnvVars.ENV_ACTIVE: "default"}):
+        result = hatch("env", "remove")
 
     assert result.exit_code == 1
     assert result.output == helpers.dedent(
@@ -324,28 +324,28 @@ def test_active(hatch, temp_dir_data, helpers):
 
 
 def test_active_override(hatch, helpers, temp_dir_data, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     project = Project(project_path)
-    helpers.update_project_environment(project, 'default', {'skip-install': True, **project.config.envs['default']})
-    helpers.update_project_environment(project, 'foo', {})
+    helpers.update_project_environment(project, "default", {"skip-install": True, **project.config.envs["default"]})
+    helpers.update_project_environment(project, "foo", {})
 
     with project_path.as_cwd():
-        result = hatch('env', 'create')
+        result = hatch("env", "create")
 
     assert result.exit_code == 0, result.output
 
-    env_data_path = temp_dir_data / 'data' / 'env' / 'virtual'
+    env_data_path = temp_dir_data / "data" / "env" / "virtual"
     assert env_data_path.is_dir()
 
     project_data_path = env_data_path / project_path.name
@@ -360,10 +360,10 @@ def test_active_override(hatch, helpers, temp_dir_data, config_file):
     env_dirs = list(storage_path.iterdir())
     assert len(env_dirs) == 1
 
-    (storage_path / 'default').is_dir()
+    (storage_path / "default").is_dir()
 
-    with project_path.as_cwd(env_vars={AppEnvVars.ENV_ACTIVE: 'foo'}):
-        result = hatch('env', 'remove', 'default')
+    with project_path.as_cwd(env_vars={AppEnvVars.ENV_ACTIVE: "foo"}):
+        result = hatch("env", "remove", "default")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -376,34 +376,34 @@ def test_active_override(hatch, helpers, temp_dir_data, config_file):
 
 
 def test_plugin_dependencies_unmet(hatch, helpers, temp_dir_data, config_file, mock_plugin_installation):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir_data.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir_data / 'my-app'
+    project_path = temp_dir_data / "my-app"
 
     project = Project(project_path)
-    helpers.update_project_environment(project, 'default', {'skip-install': True, **project.config.envs['default']})
-    helpers.update_project_environment(project, 'foo', {})
-    helpers.update_project_environment(project, 'bar', {})
+    helpers.update_project_environment(project, "default", {"skip-install": True, **project.config.envs["default"]})
+    helpers.update_project_environment(project, "foo", {})
+    helpers.update_project_environment(project, "bar", {})
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'foo')
+        result = hatch("env", "create", "foo")
 
     assert result.exit_code == 0, result.output
 
     with project_path.as_cwd():
-        result = hatch('env', 'create', 'bar')
+        result = hatch("env", "create", "bar")
 
     assert result.exit_code == 0, result.output
 
-    env_data_path = temp_dir_data / 'data' / 'env' / 'virtual'
+    env_data_path = temp_dir_data / "data" / "env" / "virtual"
     assert env_data_path.is_dir()
 
     project_data_path = env_data_path / project_path.name
@@ -418,8 +418,8 @@ def test_plugin_dependencies_unmet(hatch, helpers, temp_dir_data, config_file, m
     env_dirs = list(storage_path.iterdir())
     assert len(env_dirs) == 2
 
-    foo_env_path = storage_path / 'foo'
-    bar_env_path = storage_path / 'bar'
+    foo_env_path = storage_path / "foo"
+    bar_env_path = storage_path / "bar"
 
     assert foo_env_path.is_dir()
     assert bar_env_path.is_dir()
@@ -435,7 +435,7 @@ def test_plugin_dependencies_unmet(hatch, helpers, temp_dir_data, config_file, m
     )
 
     with project_path.as_cwd():
-        result = hatch('env', 'remove', 'bar')
+        result = hatch("env", "remove", "bar")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
